/*
 * Copyright (C) 2006 Johan Maasing johan at zoom.nu Licensed under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package nu.zoom.catonine.desktop.about;

import java.awt.BorderLayout;
import java.awt.Desktop;
import java.awt.event.ActionEvent;
import java.io.IOException;
import java.net.URI;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;

import nu.zoom.gal.error.ErrorReporter;
import nu.zoom.swing.action.AbstractTypedAction;
import nu.zoom.swing.layout.VerticalPanel;
import nu.zoom.ui.Resources;
import nu.zoom.ui.Resources.ResourceNotFoundException;

/**
 * Swing component to display the svansprogram about information.
 * 
 * @author "Johan Maasing" &lt;johan@zoom.nu&gt;
 */
class AboutComponent extends JPanel {

	private static final long serialVersionUID = 1L;
	private final Resources messages;
	private final ErrorReporter errorReporter;

	AboutComponent(final ErrorReporter errorReporter, final Resources messages) {
		super(new BorderLayout());
		this.messages = messages;
		this.errorReporter = errorReporter;
	}

	void init() {
		try {
			WebAction action = new WebAction();
			add(new JButton(action), BorderLayout.WEST);
			VerticalPanel textpanel = new VerticalPanel();
			textpanel.addRow(new JLabel(messages.getMessage("nu.zoom.catonine.about.text1")));
			textpanel.addRow(new JLabel(messages.getMessage("nu.zoom.catonine.about.text2")));
			textpanel.addRow(new JLabel(messages.getMessage("nu.zoom.catonine.about.text3")));
			add(textpanel, BorderLayout.CENTER);
		} catch (Resources.ResourceNotFoundException resourceNotFoundException) {
		}
	}

	class WebAction extends AbstractTypedAction {
		private static final long serialVersionUID = 1L;
		private final URI uri;

		public WebAction() throws ResourceNotFoundException {
			super();
			setName("");
			setIcon(messages.getIcon("nu.zoom.catonine.about.image"));
			this.uri = URI.create(messages.getMessage("nu.zoom.catonine.about.web.url"));
		}

		@Override
		public void actionPerformed(ActionEvent e) {
			try {
				Desktop.getDesktop().browse(uri);
			} catch (IOException e1) {
				errorReporter.reportError(e1);
			}
		}
	}
}
