/*
 * Copyright (C) 2006 Johan Maasing johan at zoom.nu Licensed under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package nu.zoom.catonine.desktop.about;

import javax.swing.JCheckBoxMenuItem;

import nu.zoom.gal.error.ErrorReporter;
import nu.zoom.swing.desktop.PlugIn;
import nu.zoom.swing.desktop.Workbench;
import nu.zoom.swing.desktop.WorkbenchFrame;
import nu.zoom.swing.desktop.WorkbenchListener;
import nu.zoom.swing.desktop.common.action.ToggleFrameAction;
import nu.zoom.ui.Resources;
import nu.zoom.ui.Resources.ResourceNotFoundException;

/**
 * zoom.nu desktop plug-in for displaying the Svansprogram about dialog.
 * 
 * @author "Johan Maasing" &lt;johan@zoom.nu&gt;
 */
public class AboutPlugIn implements PlugIn, WorkbenchListener {

	private final Workbench workbench;
	private final Resources messages;
	private final ErrorReporter errorReporter;

	public AboutPlugIn(final Workbench workbench, final Resources messages, final ErrorReporter errorReporter) {
		super();
		this.workbench = workbench;
		this.messages = messages;
		this.errorReporter = errorReporter;
	}

	@Override
	public void initialize() throws Exception {
		workbench.addWorkBenchListener(this);
	}

	@Override
	public void close() {
	}

	@Override
	public void start() {
		workbench.getMenuBar().addToHelpMenu(new AboutMenuItem(messages).getControl());
	}

	class AboutMenuItem extends ToggleFrameAction<JCheckBoxMenuItem> {

		private static final long serialVersionUID = 1L;

		public AboutMenuItem(Resources messages) {
			super(new JCheckBoxMenuItem());
			try {
				setName(messages.getMessage("nu.zoom.catonine.about.menuitem"));
			} catch (ResourceNotFoundException ex) {
				errorReporter.reportError(ex);
			}
		}

		@Override
		protected WorkbenchFrame createFrame() {
			AboutComponent c = new AboutComponent(errorReporter, messages);
			c.init();
			WorkbenchFrame frame = workbench.createWorkbenchFrame("catonine.about", c, true, true);
			try {
				frame.setTitle(messages.getMessage("nu.zoom.catonine.about.menuitem"));
			} catch (ResourceNotFoundException ex) {
				errorReporter.reportError(ex);
			}
			return frame;
		}

		@Override
		public void frameDetached(WorkbenchFrame frame) {
		}

		@Override
		public void frameAttached(WorkbenchFrame frame) {
		}
	}
}
